@@ -1,41 +1,39 @@
-template <typename T, typename U>
-NumericVector impl_twosample_pmt(
+template <bool progress, typename T>
+RObject impl_twosample_pmt(
     NumericVector x,
     NumericVector y,
-    const U& statistic_func,
+    const T& statistic_func,
     const double n_permu)
 {
-    T bar;
+    Stat<progress> statistic_container;
 
     auto statistic_closure = statistic_func(x, y);
-    auto twosample_update = [x, y, &statistic_closure, &bar]() {
-        return bar << statistic_closure(x, y);
+    auto twosample_update = [x, y, &statistic_closure, &statistic_container]() {
+        return statistic_container << statistic_closure(x, y);
     };
 
-    bar.init_statistic(twosample_update);
-
-    // permuting based on the shorter
-    NumericVector x_ = x.size() < y.size() ? x : y;
-    NumericVector y_ = x.size() < y.size() ? y : x;
-
-    R_len_t m = x_.size();
-    R_len_t n = x_.size() + y_.size();
+    statistic_container.init_statistic(twosample_update);
 
     if (!std::isnan(n_permu)) {
-        R_len_t i, j;
+        NumericVector x_ = x.size() < y.size() ? x : y;
+        NumericVector y_ = x.size() < y.size() ? y : x;
 
+        R_xlen_t m = x_.size();
+        R_xlen_t n = x_.size() + y_.size();
+
+        R_xlen_t i, j;
         if (n_permu == 0) {
             IntegerVector p(n, 0);
 
             for (i = m; i < n; i++) {
                 p[i] = 1;
             }
-            bar.init_statistic_permu(n_permutation(p));
+            statistic_container.init_statistic_permu(n_permutation(p));
 
             for (i = 0; i < n; i++) {
                 p[i] = i;
             }
-            auto swap_update = [x_, y_, p, m, &twosample_update](const R_len_t out, const R_len_t in) mutable {
+            auto swap_update = [x_, y_, p, m, &twosample_update](const R_xlen_t out, const R_xlen_t in) mutable {
                 std::swap(x_[p[out]], y_[p[in] - m]);
                 std::swap(p[out], p[in]);
                 twosample_update();
@@ -99,7 +97,7 @@ NumericVector impl_twosample_pmt(
                 }
             }
         } else {
-            bar.init_statistic_permu(n_permu);
+            statistic_container.init_statistic_permu(n_permu);
 
             do {
                 for (i = 0; i < m; i++) {
@@ -112,5 +110,5 @@ NumericVector impl_twosample_pmt(
         }
     }
 
-    return bar.close();
+    return statistic_container.close();
 }
